tiled.adapters.xarray.DataArrayAdapter
======================================

.. currentmodule:: tiled.adapters.xarray

.. autoclass:: DataArrayAdapter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataArrayAdapter.__init__
      ~DataArrayAdapter.from_data_array
      ~DataArrayAdapter.items
      ~DataArrayAdapter.macrostructure
      ~DataArrayAdapter.microstructure
      ~DataArrayAdapter.read
      ~DataArrayAdapter.structure
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DataArrayAdapter.metadata
      ~DataArrayAdapter.structure_family
   
   